From ac7e1cb9e571fb66891e242932a3f905ea1c12ca Mon Sep 17 00:00:00 2001
From: Pascal H <hpwxf@haveneer.com>
Date: Mon, 15 Mar 2021 10:26:48 +0100
Subject: [PATCH] Force an answer to Q2 of quiz3

Add also an example of unimplemented!() macro.
---
 exercises/quiz3.rs | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/exercises/quiz3.rs b/exercises/quiz3.rs
index a0cd371..fae0eed 100644
--- a/exercises/quiz3.rs
+++ b/exercises/quiz3.rs
@@ -24,6 +24,7 @@ mod tests {
 
     #[test]
     fn returns_twice_of_negative_numbers() {
-        // TODO write an assert for `times_two(-4)`
+        // TODO replace unimplemented!() with an assert for `times_two(-4)`
+        unimplemented!()
     }
 }